/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
typeof VMM!="undefined"&&(VMM.Language={lang:"fa",right_to_left:!0,api:{wikipedia:"fa"},date:{month:["فروردین","اردیبهشت","خورداد","تیر","امرداد","شهریور","مهر","آبان","آذر","دی","بهمن","اسفند"],month_abbr:["فروردین","اردیبهشت","خورداد","تیر","امرداد","شهریور","مهر","آبان","آذر","دی","بهمن","اسفند"],day:["یکشنبه","دوشنبه","سه شنبه","چهارشنبه","پنجشنبه","جمعه","شنبه"],day_abbr:["یکشنبه","دوشنبه","سه شنبه","چهارشنبه","پنجشنبه","جمعه","شنبه"]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"mmm d",full:"mmmm d',' yyyy",full:"mmmm d',' yyyy",time_no_seconds_short:"h:MM TT",time_no_seconds_short:"h:MM TT",full_long:"mmm d',' yyyy 'at' h:MM TT",full_long_small_date:"h:MM TT'<br/><small>mmm d',' yyyy'</small>'"},messages:{loading_timeline:"بارگذاری، شکیبا باشید...",return_to_title:"ابتدای زمانبندی",expand_timeline:"بزرگنمایی",contract_timeline:"کوچکنمایی",wikipedia:"از ویکی پدیا، دانشنامه آزاد",loading_content:"بارگذاری",loading:"بارگذاری"}});