/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Afrikaans LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"af",api:{wikipedia:"af"},date:{month:["Januarie","Februarie","Maart","April","Mei","Junie","Julie","Augustus","September","Oktober","November","Desember"],month_abbr:["Jan.","Feb.","Maart","April","Mei","Junei","Julie","Aug.","Sept.","Okt.","Nov.","Des."],day:["Sondag","Maandag","Dinsdag","Woensdag","Donderdag","Vrydag","Saterdag"],day_abbr:["Son.","Maan.","Dins.","Woen.","Don.","Vry.","Sat."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm yyyy",time_short:"HH:MM:SS",time_no_seconds_short:"HH:MM",time_no_seconds_small_date:"HH:MM'<br/><small>'d mmmm yyyy'</small>'",full_long:"d mmm',' yyyy 'om' HH:MM",full_long_small_date:"HH:MM'<br/><small>d mmm yyyy'</small>'"},messages:{loading_timeline:"Die tydlyn laai... ",return_to_title:"Begin voor",expand_timeline:"Rek die tydlyn",contract_timeline:"Krimp die tydlyn",wikipedia:"Van Wikipedia, die gratis ensiklopedie",loading_content:"Die inhoud laai",loading:"Aan't laai"}});