/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Georgian LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"ka",api:{wikipedia:"ka"},date:{month:["იანვარი","თებერვალი","მარტი","აპრილი","მაისი","ივნისი","ივლისი","აგვისტო","სექტემბერი","ოქტომბერი","ნოემბერი","დეკემბერი"],month_abbr:["იან.","თებ.","მარტი","აპრ","მაი.","ივნ.","ივლ.","აგვ.","სექ.","ოქტ.","ნოე.","დეკ."],day:["კვირა","ორშაბათი","სამშაბათი","ოთხშაბათი","ხუთშაბათი","პარასკევი","შაბათი"],day_abbr:["კვ.","ორ.","სამ.","ოთხ.","ხუთ.","პარ.","შაბ."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"mmm d",full:"mmmm d',' yyyy",time_short:"h:MM:ss TT",time_no_seconds_short:"h:MM TT",time_no_seconds_small_date:"h:MM TT'<br/><small>'mmmm d',' yyyy'</small>'",full_long:"mmm d',' yyyy 'at' h:MM TT",full_long_small_date:"h:MM TT'<br/><small>mmm d',' yyyy'</small>'"},messages:{loading_timeline:"იტვირთება თაიმლაინი... ",return_to_title:"დაბრუნდი თავში",expand_timeline:"გაშალე თაიმლაინი",contract_timeline:"Contract Timeline",wikipedia:"თავისუფალი ენციკლოპედია Wikipedia-დან",loading_content:"შინაარსის ჩამოტვირთვა",loading:"ჩამოტვირთვა"}});