/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Dutch LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"nl",api:{wikipedia:"nl"},date:{month:["januari","februari","maart","april","mei","juni","juli","augustus","september","oktober","november","december"],month_abbr:["jan","febr","maa","apr","mei","juni","juli","aug","sept","okt","nov","dec"],day:["zondag","maandag","dinsdag","woensdag","donderdag","vrijdag","zaterdag"],day_abbr:["zo","ma","di","wo","do","vr","za"]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm yyyy",time_short:"HH:MM:ss",time_no_seconds_short:"HH:MM",time_no_seconds_small_date:"HH:MM'<br/><small>'d mmmm yyyy'</small>'",full_long:"dddd',' d mmm yyyy 'om' HH:MM",full_long_small_date:"HH:MM'<br/><small>'dddd',' d mmm yyyy'</small>'"},messages:{loading_timeline:"Tijdlijn laden ... ",return_to_title:"Terug naar het begin",expand_timeline:"Tijdlijn uitzoomen",contract_timeline:"Tijdlijn inzoomen",wikipedia:"From Wikipedia, the free encyclopedia",loading_content:"Inhoud laden",loading:"Laden"}});