/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/*
    TimelineJS - ver. 2.30.0 - 2014-02-20
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*//* Russian LANGUAGE 
 ================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"ru",api:{wikipedia:"ru"},date:{month:["января","февраля","марта","апреля","мая","июня","июля","августа","сентября","октября","ноября","декабря"],month_abbr:["янв.","фев.","март","апр.","май","июнь","июль","авг.","сент.","окт.","нояб.","дек."],day:["воскресенье","понедельник","вторник","среда","четверг","пятница","суббота"],day_abbr:["вск.","пн.","вт.","ср.","чт.","пт.","сб."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm',' yyyy",time_short:"H:MM:ss",time_no_seconds_short:"H:MM",time_no_seconds_small_date:"H:MM'<br/><small>'d mmmm',' yyyy'</small>'",full_long:"d mmm',' yyyy 'в' HH:MM",full_long_small_date:"HH:MM'<br/><small>d mmm',' yyyy'</small>'"},messages:{loading_timeline:"Загрузка... ",return_to_title:"Вернуться к заголовку",expand_timeline:"Увеличить",contract_timeline:"Уменьшить",wikipedia:"Из Wikipedia",loading_content:"Загрузка контента",loading:"Загрузка"}});