/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Latvian LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"lv",api:{wikipedia:"lv"},date:{month:["Janvāris","Februāris","Marts","Aprīlis","Maijs","Jūnijs","Jūlijs","Augusts","Septembris","Oktobris","Novembris","Decembris"],month_abbr:["Jan.","Feb.","Mar.","Apr.","Mai.","Jūn.","Jūl.","Aug.","Sep.","Okt.","Nov.","Dec."],day:["Svētdiena","Pirmdiena","Otrdiena","Trešdiena","Ceturtdiena","Piektdiena","Sestdiena"],day_abbr:["Sun.","Mon.","Tues.","Wed.","Thurs.","Fri.","Sat."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"mmm d",full:"d. mmmm',' yyyy",time_short:"h:MM:ss TT",time_no_seconds_short:"HH:MM TT",time_no_seconds_small_date:"h:MM TT'<br/><small>'mmmm d',' yyyy'</small>'",full_long:"mmm d',' yyyy 'at' hh:MM TT",full_long_small_date:"hh:MM TT'<br/><small>mmm d',' yyyy'</small>'"},messages:{loading_timeline:"Ielādējas grafiks... ",return_to_title:"Atgriezties uz sākumu",expand_timeline:"Izvērst grafiku",contract_timeline:"Sašaurināt grafiku",wikipedia:"No Wikipedia, brīvās enciklopēdijas",loading_content:"Ielādējas saturs",loading:"Ielādējas"}});