/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Japanese LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"ja",api:{wikipedia:"ja"},date:{month:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],month_abbr:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],day:["日曜日","月曜日","火曜日","水曜日","木曜日","金曜日","土曜日"],day_abbr:["日","月","火","水","木","金","土"]},dateformats:{year:"yyyy年",month_short:"mmm",month:"yyyy年 m月d日 (ddd)",full_short:"yyyy年m月d日",full:"yyyy年 m月d日 (ddd)",time_short:"HH:MM:ss",time_no_seconds_short:"HH:MM",time_no_seconds_small_date:"HH:MM'<br/><small>'yyyy年m月d日'</small>'",full_long:"yyyy年m月d日 H時M分s秒",full_long_small_date:"HH:MM:ss'<br/><small>'yyyy年m月d日'</small>'"},messages:{loading_timeline:"タイムラインをロードしています…",return_to_title:"タイトルへ戻ります",expand_timeline:"タイムラインを展開します",contract_timeline:"タイムラインを縮めます",wikipedia:"出典：フリー百科事典『ウィキペディア（Wikipedia）』",loading_content:"コンテンツをロードしています",loading:"ローディング"}});