/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Sinhalese LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"si",api:{wikipedia:"si"},date:{month:["ජනවාරි","පෙබරවාරි","මාර්තු","අප්‍රේල්","මැයි","ජූනි","ජූලි","අගෝස්තු","සැප්තැම්බර්","ඔක්තෝම්බර්","නොවැම්බර්","දෙසැම්බර්"],month_abbr:["ජන.","පෙබ.","මාර්තු","අප්‍රේල්","මැයි","ජුනි","ජුලි","අගෝ.","සැප්.","ඔක්.","නොවැ.","දෙසැ."],day:["ඉරිදා","සදුදා","අගහරුවදා","බදාදා","බ්‍රහස්පතින්දා","සිකුරාදා","සෙනසුරාදා"],day_abbr:["ඉරි.","සදු.","අග.","බදා.","බ්‍රහස්.","සිකු.","සෙන."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"mmm d",full:"mmmm d',' yyyy",time_no_seconds_short:"h:MM TT",time_no_seconds_small_date:"h:MM TT'<br/><small>'mmmm d',' yyyy'</small>'",full_long:"mmm d',' yyyy 'at' h:MM TT",full_long_small_date:"h:MM TT'<br/><small>mmm d',' yyyy'</small>'"},messages:{loading_timeline:"කාල රේඛාව ලෝඩ් වෙමින්... ",return_to_title:"නැවත මාතෘකාවට",expand_timeline:"කාල රේඛාව විහිදන්න",contract_timeline:"කාල රේඛාව අකුලන්න",wikipedia:"විකිපීඩියා, නිදහස් විශ්වකෝෂය වෙතින්",loading_content:"අන්තර්ගතය ලෝඩ් වෙමින්",loading:"ලෝඩ් වෙමින්"}});