/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Serbian (Latin) LANGUAGE
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"sr",api:{wikipedia:"sr"},date:{month:["januar","Februar","Mart","April","Maj","Jun","Jul","Avgust","Septembar","Oktobar","Novembar","Decembar"],month_abbr:["Jan.","Feb.","Mart","Apr.","Maj","Jun","Jul","Avg.","Sep.","Okt.","Nov.","Dec."],day:["Nedelja","Ponedeljak","Utorak","Sreda","Četvratk","Petak","Subota"],day_abbr:["Ned.","Pon.","Uto.","Sre.","Čet.","Pet.","Sub."]},dateformats:{year:"yyyy.",month_short:"mmm",month:"mmmm yyyy.",full_short:"d. mmm",full:"d. mmmm yyyy.",time_short:"HH:MM:ss",time_no_seconds_short:"HH:MM",time_no_seconds_small_date:"HH:MM'<br/><small>'d. mmmm yyyy.'</small>'",full_long:"d. mmm yyyy. 'u' HH:MM",full_long_small_date:"HH:MM'<br/><small>d. mmm yyyy.'</small>'"},messages:{loading_timeline:"Učitavanje... ",return_to_title:"Početak",expand_timeline:"Uvećaj",contract_timeline:"Umanji",wikipedia:"Iz Vikipedije, slobodne enciklopedije",loading_content:"Sadržaj se učitava",loading:"Učitava se"}});