/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Tamil LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"ta",api:{wikipedia:"ta"},date:{month:["ஜனவரி","பெப்ரவரி","மார்ச்","ஏப்ரல்","மே","ஜுன்","ஜுலை","ஆகஸ்ட்","செப்டம்பர்","ஒக்டோபர்","நவம்பர்","டிசம்பர்"],month_abbr:["ஜன.","பெப்.","மார்ச்","ஏப்ரல்","மே","ஜுன்","ஜுலை","ஆகஸ்ட்","செப்ட்.","ஒக்டோ.","நவம்பர்","டிசம்பர்"],day:["ஞாயிறு","திங்கள்","செவ்வாய்","புதன்","வியாழன்","வெள்ளி","சனி"],day_abbr:["ஞா","தி","செ","பு","வி","வெ","சனி"]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"mmm d",full:"mmmm d',' yyyy",time_short:"h:MM:ss TT",time_no_seconds_short:"h:MM TT",time_no_seconds_small_date:"h:MM TT'<br/><small>'mmmm d',' yyyy'</small>'",full_long:"mmm d',' yyyy 'at' hh:MM TT",full_long_small_date:"hh:MM TT'<br/><small>mmm d',' yyyy'</small>'"},messages:{loading_timeline:"நேரக்கோடு தரவேறுகிறது.... ",return_to_title:"தலைப்பிற்குச் செல்ல",expand_timeline:"நேரக்கோட்டை விரிக்க",contract_timeline:"நேரக்கோட்டை சுருக்க",wikipedia:"கட்டற்ற கலைக்களஞ்சியம், விக்கிப்பீடியாவிலிருந்து",loading_content:"உள்ளடக்கம் தரவேறுகிறது...",loading:"தரவேறுகிறது"}});