/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Luxembourgish LANGUAGE
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"lb",api:{wikipedia:"lb"},date:{month:["Januar","Februar","Mäerz","Abrëll","Mee","Juni","Juli","August","September","Oktober","November","Dezember"],month_abbr:["Jan.","Feb.","Mäe.","Abr.","Mee","Jun.","Jul","Aug.","Sept.","Okt.","Nov.","Dez."],day:["Sonndeg","Méindeg","Dënschdeg","Mëttwoch","Donneschden","Freiden","Samschden"],day_abbr:["Son.","Méi.","Dë.","Më.","Do.","Fr.","Sa."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"mmm d",full:"d'.' mmmm yyyy",time_short:"hh:MM:ss",time_no_seconds_short:"hh:MM",time_no_seconds_small_date:"h:MM TT'<br/><small>'d'.' mmmm yyyy'</small>'",full_long:"d'.' mmm yyyy 'um' hh:MM TT",full_long_small_date:"hh:MM'<br/><small>d'.' mmm yyyy'</small>'"},messages:{loading_timeline:"Timeline gëtt gelueden... ",return_to_title:"Zeréck zum Titel",expand_timeline:"Timeline vergréisseren",contract_timeline:"Timeline verklengeren",wikipedia:"Vu Wikipedia, der fräier Enzyklopedie",loading_content:"Inhalt lued",loading:"Lued"}});