/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Telugu LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"te",api:{wikipedia:"te"},date:{month:["జనవరి","ఫిబ్రవరి","మార్చి","ఏప్రిల్","మే","జూన్","జూలై","ఆగస్ట్","సెప్టెంబర్","అక్టోబర్","నవంబర్","డిసెంబర్"],month_abbr:["జన.","ఫిబ్ర.","మార్చి","ఏప్రి.","మే","జూన్","జూలై","ఆగ.","సెప్టెం.","అక్టో.","నవం.","డిసెం."],day:["ఆదివారం","సోమవారం","మంగళవారం","బుధవారం","గురువారం","శుక్రవారం","శనివారం"],day_abbr:["ఆది.","సోమ.","మంగళ.","బుధ.","గురు.","శుక్ర.","శని."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"mmm d",full:"mmmm d',' yyyy",time_no_seconds_short:"h:MM TT",time_no_seconds_small_date:"h:MM TT'<br/><small>'mmmm d',' yyyy'</small>'",full_long:"mmm d',' yyyy 'at' h:MM TT",full_long_small_date:"h:MM TT'<br/><small>mmm d',' yyyy'</small>'"},messages:{loading_timeline:"టైమ్‌లైన్ లోడవుతూంది... ",return_to_title:"తిరిగి మొదటి స్లైడుకి",expand_timeline:"టైమ్‌లైన్‌ను విస్తరించండి",contract_timeline:"టైమ్‌లైన్‌ను కుదించండి",wikipedia:"స్వేచ్ఛా విజ్ఞాన సర్వస్వమైన వికీపీడియా నుండి",loading_content:"విషయం లోడవుతూంది",loading:"లోడవుతూంది"}});