/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Serbian (Cyrillic) LANGUAGE
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"рп",api:{wikipedia:"рп"},date:{month:["Јануар","Фебруар","Март","Април","Мај","Јун","Јул","Август","Септембар","Октобар","Новембар","Децембар"],month_abbr:["Јан.","Феб.","Март","Апр.","Мај","Јун","Јул","Авг.","Сеп.","Окт.","Нов.","Дец."],day:["Недеља","Понедељак","Уторак","Среда","Четвртак","Петак","Субота"],day_abbr:["Нед.","Пон.","Уто.","Сре.","Чет.","Пет.","Суб."]},dateformats:{year:"yyyy.",month_short:"mmm",month:"mmmm yyyy.",full_short:"d. mmm",full:"d. mmmm yyyy.",time_short:"HH:MM:ss",time_no_seconds_short:"HH:MM",time_no_seconds_small_date:"HH:MM'<br/><small>'d. mmmm yyyy.'</small>'",full_long:"d. mmm yyyy. 'u' HH:MM",full_long_small_date:"HH:MM'<br/><small>d. mmm yyyy.'</small>'"},messages:{loading_timeline:"Учитавање... ",return_to_title:"Почетак",expand_timeline:"Увећај",contract_timeline:"Умањи",wikipedia:"Из Википедије, слободне енциклопедије",loading_content:"Садржај се учитава",loading:"Учитава се"}});