/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Romanian LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"ro",api:{wikipedia:"ro"},date:{month:["Ianuarie","Februarie","Martie","Aprilie","Mai","Iunie","Iulie","August","Septembrie","Octombrie","Noiembrie","Decembrie"],month_abbr:["Ian.","Feb.","Mar.","Apr.","Mai","Iun.","Iul.","Aug.","Sep.","Oct.","Noi.","Dec."],day:["Duminică","Luni","Marți","Miercuri","Joi","Vineri","Sâmbătă"],day_abbr:["Dum.","Luni","Mar.","Mie.","Joi","Vin.","Sâm."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm',' yyyy",time_short:"h:MM:ss TT",time_no_seconds_short:"h:MM TT",time_no_seconds_small_date:"h:MM TT'<br/><small>'d mmmm',' yyyy'</small>'",full_long:"d mmm',' yyyy 'at' h:MM TT",full_long_small_date:"h:MM TT'<br/><small>d mmm',' yyyy'</small>'"},messages:{loading_timeline:"Se încarcă cronologia... ",return_to_title:"Înapoi la titlu",expand_timeline:"Extinde cronologia",contract_timeline:"Restrânge cronologia",wikipedia:"De pe Wikipedia, enciclopedia gratuită",loading_content:"Se încarcă conținutul",loading:"Se încarcă"}});