/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Croatian (Latin) LANGUAGE
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"hr",api:{wikipedia:"hr"},date:{month:["siječnja","veljače","ožujka","travnja","svibnja","lipnja","srpnja","kolovoza","rujna","listopada","studenog","prosinca"],month_abbr:["I","II","III","IV","V","VI","VII","VIII","IX","X","XI","XII"],day:["nedjelja","ponedjeljak","utorak","srijeda","četvrtak","petak","subota"],day_abbr:["ned","pon","uto","sri","čet","pet","sub"]},dateformats:{year:"yyyy.",month_short:"mmm",month:"mmmm yyyy.",full_short:"dd. mmm",full:"dd. mmmm yyyy.",time_short:"HH:MM:ss",time_no_seconds_short:"HH:MM",time_no_seconds_small_date:"HH:MM'<br/><small>'dd. mmmm yyyy.'</small>'",full_long:"dd. mmmm yyyy. 'u' HH:MM",full_long_small_date:"HH:MM'<br/><small>dd. mmm yyyy.'</small>'"},messages:{loading_timeline:"Učitavanje... ",return_to_title:"Početak",expand_timeline:"Povećaj",contract_timeline:"Smanji",wikipedia:"Iz Vikipedije, slobodne enciklopedije",loading_content:"Sadržaj se učitava",loading:"Učitava se"}});