/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Basque/ Euskara LANGUAGE
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"eu",api:{wikipedia:"eu"},date:{month:["Urtarrila","Otsaila","Martxoa","Apirila","Maiatza","Ekaina","Uztaila","Abuztua","Iraila","Urria","Azaroa","Abendua"],month_abbr:["Urt.","Ots.","Mar.","Api.","Mai.","Eka.","Uzt.","Abu.","Ira.","Urr.","Aza.","Abe."],day:["Igandea","Astelehena","Asteartea","Asteazkena","Osteguna","Ostirala","Larunbata"],day_abbr:["Iga.","Asl.","Asr.","Asz.","Osg.","Osr.","Lar."]},dateformats:{year:"yyyy",month_short:"mmm",month:"yyyy'(e)ko' mmmm",full_short:"mmm'-'d",full:"yyyy'(e)ko' mmmm'k' d",time_short:"h:MM:SS TT",time_no_seconds_short:"h:MM TT",time_no_seconds_small_date:"h:MM TT'<br /><small>'yyyy'-'mmm'-'d'</small>",full_long:"yyyy'(e)ko' mmmm'ren' d'(e)an,' hh:MM TT'(r)etan'",full_long_small_date:"hh:MM TT'<br /><small>'yyyy'-'mmm'-'d'</small>"},messages:{loading_timeline:"Kronologia kargatzen...",return_to_title:"Titulura itzuli",expand_timeline:"Handiago ikusi",contract_timeline:"Txikiago ikusi",wikipedia:"Wikipedia entziklopedia libretik",loading_content:"Edukia kargatzen",loading:"Kargatzen"}});