/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Danish LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"da",api:{wikipedia:"da"},date:{month:["januar","februar","marts","april","maj","juni","juli","august","september","oktober","november","december"],month_abbr:["jan.","feb.","mar.","apr.","maj.","jun.","jul.","aug.","sep.","okt.","nov.","dec."],day:["søndag","mandag","tirsdag","onsdag","torsdag","fredag","lørdag"],day_abbr:["sø.","ma.","ti.","on.","to.","fr.","lø."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d. mmm",full:"d. mmmm',' yyyy",time_short:"HH:MM:ss",time_no_seconds_short:"HH:MM",time_no_seconds_small_date:"HH:MM'<br/><small>'d. mmmm',' yyyy'</small>'",full_long:"dddd',' d. mmm',' yyyy 'um' HH:MM",full_long_small_date:"HH:MM'<br/><small>'dddd',' d. mmm yyyy'</small>'"},messages:{loading_timeline:"Henter tidslinie...",return_to_title:"Tilbage til titel",expand_timeline:"Udvid tidslinien",contract_timeline:"Træk tidslinien sammen",wikipedia:"Fra Wikipedia",loading_content:"Henter indhold",loading:"Henter"}});