/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/*
    TimelineJS - ver. 2.30.0 - 2014-02-20
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*//* Ukrainian LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"uk",api:{wikipedia:"uk"},date:{month:["січня","лютого","березня","квітня","травня","червня","липня","серпня","вересня","жовтня","листопада","грудня"],month_abbr:["січ.","лют.","берез.","квіт.","трав.","черв.","лип.","серп.","вер.","жовт.","листоп.","груд."],day:["неділя","понеділок","вівторок","середа","четвер","п'ятниця‎","субота"],day_abbr:["нд.","пн.","вт.","ср.","чт.","пт.","сб."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm',' yyyy",time_short:"H:MM:ss",time_no_seconds_short:"H:MM",time_no_seconds_small_date:"H:MM'<br/><small>'d mmmm',' yyyy'</small>'",full_long:"d mmm yyyy 'у' H:MM",full_long_small_date:"H:MM'<br/><small>d mmm',' yyyy'</small>'"},messages:{loading_timeline:"Завантаження...",return_to_title:"Повернутися до початку",expand_timeline:"Збільшити",contract_timeline:"Зменьшити",wikipedia:"З Wikipedia, вільної енциклопедії",loading_content:"Завантаження вмісту",loading:"Завантаження"}});