/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Nepali LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"ne",api:{wikipedia:"ne"},date:{month:["जनवरी","फेब्रुवरी","मार्च","अप्रिल","मे","जून","जुलाई","अगस्ट","सेप्टेम्बर","अक्टोबर","नोभेम्बर","डिसेम्बर"],month_abbr:["जनवरी","फेब्रुवरी","मार्च","अप्रिल","मे","जून","जुलाई","अगस्ट","सेप्टेम्बर","अक्टोबर","नोभेम्बर","डिसेम्बर"],day:["आइतबार","सोमबार","मंगलबार","बुधबार","बिहिबार","शुक्रबार","शनिबार"],day_abbr:["आइतबार","सोमबार","मंगलबार","बुधबार","बिहिबार","शुक्रबार","शनिबार"]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"mmm d",full:"mmmm d',' yyyy",time_short:"h:MM:ss TT",time_no_seconds_short:"h:MM TT",time_no_seconds_small_date:"h:MM TT'<br/><small>'mmmm d',' yyyy'</small>'",full_long:"mmm d',' yyyy 'at' h:MM TT",full_long_small_date:"h:MM TT'<br/><small>mmm d',' yyyy'</small>'"},messages:{loading_timeline:"टाइमलाइन लोड हुदैछ... ",return_to_title:"शीर्षकमा फर्कनुहोस्",expand_timeline:"टाइमलाइन लामो बनाउनुहोस्",contract_timeline:"टाइमलाइन छोटो बनाउनुहोस्",wikipedia:"विकिपिडियाबाट",loading_content:"सामग्री लोड हुदैछ",loading:"लोड हुदैछ"}});