/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Estonian LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"et",api:{wikipedia:"et"},date:{month:["jaanuar","veebruar","märts","aprill","mai","juuni","juuli","august","september","oktoober","november","detsember"],month_abbr:["jaan.","veebr.","märts","apr.","mai","juuni","juuli","aug.","sept.","okt.","nov.","dets."],day:["pühapäev","esmaspäev","teisipäev","kolmapäev","neljapäev","reede","laupäev"],day_abbr:["P","E","T","K","N","R","L"]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"mmm d",full:"mmmm d',' yyyy",time_short:"h:MM:ss TT",time_no_seconds_short:"h:MM TT",time_no_seconds_small_date:"h:MM TT'<br/><small>'mmmm d',' yyyy'</small>'",full_long:"mmm d',' yyyy 'at' h:MM TT",full_long_small_date:"h:MM TT'<br/><small>mmm d',' yyyy'</small>'"},messages:{loading_timeline:"Laadib ajajoont… ",return_to_title:"Tagasi algusse",expand_timeline:"Vaata lähemalt",contract_timeline:"Vaata kaugemalt",wikipedia:"Wikipedia, vaba entsüklopeedia",loading_content:"Laadib sisu",loading:"Laadib"}});