/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Malay LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"ms",api:{wikipedia:"ms"},date:{month:["Januari","Februari","Mac","April","Mei","Jun","Julai","Ogos","September","Oktober","November","Disember"],month_abbr:["Jan.","Feb.","Mac","Apr","Mei","Jun","Jul","Ogos.","Sept.","Okt.","Nov.","Dis."],day:["Ahad","Isnin","Selasa","Rabu","Khamis","Jumaat","Sabtu"],day_abbr:["Ahd.","Isn.","Sel.","Rab.","Kha.","Jum.","Sab."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm yyyy",time_short:"h:MM:ss TT",time_no_seconds_short:"h:MM TT",time_no_seconds_small_date:"h:MM TT'<br/><small>'d mmmm yyyy'</small>'",full_long:"d mmm yyyy 'jam' h:MM TT",full_long_small_date:"h:MM TT'<br/><small>d mmm yyyy'</small>'"},messages:{loading_timeline:"Memuat Garis Masa... ",return_to_title:"Kembali ke Tajuk",expand_timeline:"Besarkan Garis Masa",contract_timeline:"Kecilkan Garis Masa",wikipedia:"Daripada Wikipedia, ensiklopedia bebas.",loading_content:"Memuat Kandungan",loading:"Memuat"}});