/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Galician LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"gl",api:{wikipedia:"gl"},date:{month:["Xaneiro","Febreiro","Marzo","Abril","Maio","Xuño","Xullo","Agosto","Setembro","Outubro","Novembro","Decembro"],month_abbr:["Xan.","Feb.","Mar.","Abr.","Mai.","Xuñ.","Xul.","Ago.","Set.","Out.","Nov.","Dec."],day:["Domingo","Luns","Martes","Mércores","Xoves","Venres","Sábado"],day_abbr:["Dom.","Lun.","Mar.","Mér.","Xov.","Ven.","Sáb."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm yyyy",time_short:"HH:MM:SS",time_no_seconds_short:"HH:MM",time_no_seconds_small_date:"HH:MM'<br/><small>'d mmmm yyyy'</small>'",full_long:"dddd',' d mmm yyyy 'um' HH:MM",full_long_small_date:"HH:MM'<br/><small>'dddd',' d mmm yyyy'</small>'"},messages:{loading_timeline:"Cronoloxía esta cargando",return_to_title:"Volver ao título",expand_timeline:"Alongar a cronoloxía",contract_timeline:"Acurtar a cronoloxía",wikipedia:"Dende Wikipedia, a enciclopedia libre",loading_content:"cargando",loading:"cargando"}});