/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Hebrew (beta) LANGUAGE 
================================================== */trace("Language code 'iw' for Hebrew is deprecated. Use 'he' instead.");typeof VMM!="undefined"&&(VMM.Language={lang:"iw",right_to_left:!0,api:{wikipedia:"he"},date:{month:["ינואר","פברואר","מרץ","אפריל","מאי","יוני","יולי","אוגוסט","ספטמבר","אוקטובר","נובמבר","דצמבר"],month_abbr:["ינואר","פברואר","מרץ","אפריל","מאי","יוני","יולי","אוגוסט","ספטמבר","אוקטובר","נובמבר","דצמבר"],day:["ראשון","שני","שלישי","רביעי","חמישי","שישי","שבת"],day_abbr:["יום א'","יום ב'","יום ג'","יום ד'","יום ה'","יום ו'","שבת"]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm,' yyyy",time_short:"h:MM:ss TT",time_no_seconds_short:"h:MM TT",time_no_seconds_small_date:"h:MM TT'<br/><small>'mmmm d',' yyyy'</small>'",full_long:"d' mmm,' yyyy 'at' h:MM TT",full_long_small_date:"h:MM TT'<br/><small>mmm d',' yyyy'</small>'"},messages:{loading_timeline:"טוען את ציר הזמן... ",return_to_title:"חזור לכותרת",expand_timeline:"הרחב את ציר הזמן",contract_timeline:"צמצם את ציר הזמן",wikipedia:"מויקיפדיה, האינציקלופדיה החופשית",loading_content:"התוכן בטעינה...",loading:"טוען..."}});