/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Brazilian Portuguese LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"pt-br",api:{wikipedia:"pt"},date:{month:["Janeiro","Fevereiro","Março","Abril","Maio","Junho","Julho","Agosto","Setembro","Outubro","Novembro","Dezembro"],month_abbr:["Jan.","Fev.","Mar.","Abr.","Mai.","Jun.","Jul.","Ago.","Set.","Out.","Nov.","Dez."],day:["Domingo","Segunda","Terça","Quarta","Quinta","Sexta","Sábado"],day_abbr:["Dom.","Seg.","Ter.","Qua.","Qui.","Sex.","Sáb."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm 'de' yyyy",full_short:"d 'de' mmm",full:"d 'de' mmmm',' yyyy",time_short:"h:MM:ss TT",time_no_seconds_short:"hh:MM TT",time_no_seconds_small_date:"hh:MM TT'<br/><small>'d 'de' mmmm',' yyyy'</small>'",full_long:"dddd',' d 'de' mmm',' yyyy 'às' hh:MM TT",full_long_small_date:"hh:MM TT'<br/><small>'dddd',' d 'de' mmm',' yyyy'</small>'"},messages:{loading_timeline:"Carregando Timeline... ",return_to_title:"Voltar para o título",expand_timeline:"Expandir Timeline",contract_timeline:"Contrair Timeline",wikipedia:"Wikipedia, A enciclopédia livre",loading_content:"Carregando Conteúdo",loading:"Carregando"}});