/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Slovenian LANGUAGE SLOVENIAN
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"sl",api:{wikipedia:"sl"},date:{month:["januar","februar","marec","april","maj","junij","julij","avgust","september","oktober","november","december"],month_abbr:["jan.","feb.","marec","april","maj","junij","july","avg.","sept.","okt.","nov.","dec."],day:["nedelja","ponedeljek","torek","sreda","čertek","petek","sobota"],day_abbr:["ned.","pon.","tor.","sre.","čet.","pet.","sob."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm yyyy",time_short:"h:MM:ss TT",time_no_seconds_short:"h:MM",time_no_seconds_small_date:"h:MM' 'd mmmm' 'yyyy",full_long:"d mmm yyyy 'ob' hh:MM",full_long_small_date:"hh:MM' d mmm yyyy"},messages:{loading_timeline:"Nalagam časovni trak... ",return_to_title:"Nazaj na naslov",expand_timeline:"Razširi časovni trak",contract_timeline:"Pokrči časovni trak",wikipedia:"Vir Wikipedija",loading_content:"Nalaganje vsebine",loading:"Nalaganje"}});