/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Icelandic LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"is",api:{wikipedia:"is"},date:{month:["janúar","febrúar","mars","apríl","maí","júní","júlí","ágúst","september","október","nóvember","desember"],month_abbr:["jan.","feb.","mars","apríl","maí","júní","júlí","ágúst","sept.","okt.","nóv.","des."],day:["sunnudagur","mánudagur","þriðjudagur","miðvikudagur","fimmtudagur","föstudagur","laugardagur"],day_abbr:["sun.","mán.","þri.","mið.","fim.","fös.","lau."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"mmm d",full:"mmmm d',' yyyy",time_short:"h:MM:SS TT",time_no_seconds_short:"hh:MM TT",time_no_seconds_small_date:"hh:MM TT'<br/><small>'mmmm d',' yyyy'</small>'",full_long:"dddd',' mmm d',' yyyy 'at' hh:MM TT",full_long_small_date:"hh:MM TT'<br/><small>'dddd',' mmm d',' yyyy'</small>'"},messages:{loading_timeline:"Raða upp tímalínu... ",return_to_title:"Til baka á forsíðu",expand_timeline:"Stækka tímalínu",contract_timeline:"Minnka tímalínu",wikipedia:"From Wikipedia, the free encyclopedia",loading_content:"Raða",loading:"Raða"}});