/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Czech LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"cz",api:{wikipedia:"cs"},date:{month:["ledna","února","března","dubna","května","června","července","srpna","září","října","listopadu","prosince"],month_abbr:["Led","Úno","Bře","Dub","Kvě","Čen","Čec","Srp","Zář","Říj","Lis","Pro"],day:["neděle","pondělí","úterý","středa","čtvrtek","pátek","sobota"],day_abbr:["Ne","Po","Út","St","Čt","Pá","So"]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d. mmm ",full:"d. mmmm yyyy",time_short:"HH:MM:SS",time_no_seconds_short:"HH:MM",time_no_seconds_small_date:"HH:MM'<br/><small>'d. mmmm yyyy'</small>'",full_long:"dddd d. mmm yyyy 'v' HH:MM",full_long_small_date:"HH:MM'<br/><small>dddd d. mmm yyyy'</small>'"},messages:{loading_timeline:"Načítám časovou osu... ",return_to_title:"Zpět na začátek",expand_timeline:"Rozbalit časovou osu",contract_timeline:"Sbalit časovou osu",wikipedia:"Zdroj: otevřená encyklopedie Wikipedia",loading_content:"Nahrávám obsah",loading:"Nahrávám"}});