/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Armenian LANGUAGE
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"hy",api:{wikipedia:"hy"},date:{month:["Հունվար","Փետրվար","Մարտ","Ապրիլ","Մայիս","Հունիս","Հուլիս","Օգոստոս","Սեպտեմբեր","Հոկտեմբեր","Նոյեմբեր","Դեկտեմբեր"],month_abbr:["Հնվ.","Փետ.","Մար","Ապր","Մայ","Հուն","Հուլ","Օգս.","Սեպ.","Հոկ.","Նոյ.","Դեկ."],day:["Կիրակի","Երկուշաբթի","Երեքշաբթի","Չորեքշաբթի","Հինգշաբթի","Ուրբաթ","Շաբաթ"],day_abbr:["Կի.","Եկ.","Եք.","Չո.","Հի.","Ու.","Շա."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm',' yyyy",time_short:"HH:MM:SS",time_no_seconds_short:"H:MM",time_no_seconds_small_date:"H:MM'<br/><small>'d mmmm',' yyyy'</small>'",full_long:"d mmm',' yyyy 'at' H:MM",full_long_small_date:"H:MM '<br/><small>d mmm',' yyyy'</small>'"},messages:{loading_timeline:"Ժամանակագրությունը բեռնվում է... ",return_to_title:"Վերադառնալ վերնագրին",expand_timeline:"Լայնացնել ժամանակագրությունը",contract_timeline:"Նեղացնել ժամանակագրությունը",wikipedia:"Ըստ Վիքիպեդիա ազատ հանրագիտարանի",loading_content:"Բովանդակությունը բեռնվում է",loading:"Բեռնում"}});