/*
    TimelineJS - ver. 2.33.1 - 2014-06-24
    Copyright (c) 2012-2013 Northwestern University
    a project of the Northwestern University Knight Lab, originally created by Zach Wise
    https://github.com/NUKnightLab/TimelineJS
    This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
    If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/* Indonesian LANGUAGE 
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"id",api:{wikipedia:"id"},date:{month:["Januari","Februari","Maret","April","Mei","Juni","Juli","Agustus","September","Oktober","November","Desember"],month_abbr:["Jan.","Feb.","Maret","April","Mei","Juni","July","Agus.","Sept.","Okt.","Nov.","Des."],day:["Ahad","Senin","Selasa","Rabu","Kamis","Jum'at","Sabtu"],day_abbr:["Ahad","Sen.","Sel.","Rabu","Kamis","Jum.","Sab."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm yyyy",time_short:"HH:MM:SS",time_no_seconds_short:"HH:MM",time_no_seconds_small_date:"HH:MM'<br/><small>'d mmmm yyyy'</small>'",full_long:"dddd',' d mmm yyyy 'pukul' HH:MM",full_long_small_date:"HH:MM'<br/><small>'dddd',' d mmm yyyy'</small>'"},messages:{loading_timeline:"Memuat Timeline... ",return_to_title:"Kembali ke Judul",expand_timeline:"Kembangkan Timeline",contract_timeline:"Ciutkan Timeline",wikipedia:"dari Wikipedia, ensiklopedia bebas",loading_content:"Memuat Isi",loading:"Memuat"}});